pub enum GitOidParseError {
Empty,
InvalidLength(usize),
InvalidShortLength(usize),
NonHexCharacter {
index: usize,
character: char,
},
UnknownKind,
}Expand description
Error returned while parsing object identifier text.
Variants
Empty
The supplied identifier text was empty.
InvalidLength(usize)
The full identifier length was not a supported shape.
InvalidShortLength(usize)
The short identifier length was outside the accepted range.
NonHexCharacter
The identifier contained a non-hexadecimal character.
UnknownKind
The object identifier kind label was not recognized.